@@ -1,9 +1,16 @@
 #!/bin/sh
 
 UPSTREAM="${UPSTREAM:-https://api.openshift.com/api/upgrades_info/v1/graph}"
-CHANNEL="${CHANNEL:-stable-4.3}"
+CHANNEL="${CHANNEL:-stable-4.7}"
 ARCH="${ARCH:-amd64}"
 VERSION="$1"
+OUTPUT=$(mktemp)
+
+# Register function to be called on EXIT to remove tmp file
+function cleanup {
+  rm -f "${OUTPUT}"
+}
+trap cleanup EXIT
 
 if test -z "${VERSION}" -o "$#" -ne 1
 then
@@ -11,14 +18,12 @@ then
 	exit 1
 fi
 
-URI="${UPSTREAM}?channel=${CHANNEL}&arch=${ARCH}"
-DATA="$(curl --silent --location --header 'Accept:application/json' "${URI}")"
-if test -z "${DATA}"
-then
+if ! curl --silent --location --fail --header 'Accept:application/json' "${UPSTREAM}?channel=${CHANNEL}&arch=${ARCH}" -o "${OUTPUT}"; then
 	 echo "Failed to fetch data from ${URI}"
+   exit 1
 fi
 
-echo "${DATA}" | jq -r "
+cat "${OUTPUT}" | jq -r "
   (.nodes | with_entries(.key |= tostring)) as \$nodes_by_index |
   [
     .edges[] |
