@@ -12,7 +12,7 @@ mkdir -p /opt/cincinnati/bin
 
 cd e2e
 mapfile -t tests < <(
-  RUST_BACKTRACE=full cargo build --tests --features test-e2e-prom-query --message-format=json |
+  RUST_BACKTRACE=full cargo build --tests --features test-e2e-prom-query --verbose --message-format=json |
     jq -r 'select(.profile.test == true) | .executable'
   )
 
